@@ -10,7 +10,7 @@ use Carp;
 
 our @EXPORT = qw( cpan_version );
 
-our $VERSION = '2.127_04';
+our $VERSION = '2.127';
 
 =encoding utf8
 
@@ -53,10 +53,7 @@ sub _metacpan {
 sub cpan_version {
 	my $self = shift;
 
-	# One reason for failure is that this is a new module not yet
-	# on CPAN
-	my $module = eval { _metacpan()->module( $self->module_name ) };
-	return unless $module;
+	my $module = _metacpan()->module( $self->module_name );
 
 	my $date    = $module->{data}{date};
 	my $version = $module->{data}{version};
